@@ -14,4 +14,4 @@ APP_ICON = media_res_url('icons/mail-accounts.svg')
 MSG_APP_CAPTION = lazy_gettext("Mails", 'system.mail')
 MSG_PERMISSION = lazy_gettext("Administer mails", 'system.mail')
 
-PERMISSION = 'admin_mail'
+PERMISSION = 'adminMail'
